@@ -14,7 +14,7 @@ int32_t SPVM__Sys__IO__DirStream__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   // File handle
   void* obj_self = stack[0].oval;
   
-  int32_t closed = env->get_field_byte_by_name(env, stack, obj_self, "closed", &e, FILE_NAME, __LINE__);
+  int32_t closed = env->get_field_byte_by_name(env, stack, obj_self, "closed", &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   DIR* dir_stream = (DIR*)env->get_pointer(env, stack, obj_self);
@@ -24,7 +24,7 @@ int32_t SPVM__Sys__IO__DirStream__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   if (!closed) {
     int32_t status = closedir(dir_stream);
     if (status == -1) {
-      env->die(env, stack, "[System Error]closedir failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+      env->die(env, stack, "[System Error]closedir failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
       return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
     }
     env->set_pointer(env, stack, obj_self, NULL);
