@@ -38,19 +38,19 @@ The destructor.
 
 =head2 sa_family
 
-  method sa_family : byte ()
+  method sa_family : int ()
 
 Gets C<sa_family>. This is the overriden method of the L<sa_family|SPVM::Sys::Socket::Sockaddr/"sa_family"> method in the Sys::Socket::Sockaddr class.
 
 =head2 sin_family
 
-  method sin_family : byte ();
+  method sin_family : int ();
   
 Gets C<sin_family>.
 
 =head2 set_sin_family
 
-  method set_sin_family : void ($family : byte);
+  method set_sin_family : void ($family : int);
 
 Sets C<sin_family>.
 
@@ -68,13 +68,13 @@ Sets C<sin_addr>. This is a L<Sys::Socket::In_addr|SPVM::Sys::Socket::In_addr> o
 
 =head2 sin_port
 
-  method sin_port : short ();
+  method sin_port : int ();
 
 Gets C<sin_port>.
 
 =head2 set_sin_port
 
-  method set_sin_port : void ($port : short);
+  method set_sin_port : void ($port : int);
 
 Sets C<sin_port>.
 
